CronStreamError

Enum CronStreamError 

pub enum CronStreamError<Tz: TimeZone> {
    OutOfRangeError {
        inner: OutOfRangeError,
        tick: DateTime<Tz>,
    },
}
Represents an error emitted by CronStream polling

Variants



OutOfRangeError

The cron stream might not always be polled consistently, such as when the worker is blocked. If polling is delayed, some ticks may be skipped. When this occurs, an out-of-range error is triggered because the missed tick is now in the past.

Fields

inner: OutOfRangeError

The inner error

tick: DateTime<Tz>

The missed tick